aboutsummaryrefslogtreecommitdiffstats
path: root/host/lib/usrp/e100/clock_ctrl.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'host/lib/usrp/e100/clock_ctrl.hpp')
-rw-r--r--host/lib/usrp/e100/clock_ctrl.hpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/host/lib/usrp/e100/clock_ctrl.hpp b/host/lib/usrp/e100/clock_ctrl.hpp
index f3a6de0fa..7c16649d3 100644
--- a/host/lib/usrp/e100/clock_ctrl.hpp
+++ b/host/lib/usrp/e100/clock_ctrl.hpp
@@ -18,7 +18,7 @@
#ifndef INCLUDED_USRP_E100_CLOCK_CTRL_HPP
#define INCLUDED_USRP_E100_CLOCK_CTRL_HPP
-#include "e100_iface.hpp"
+#include <uhd/types/serial.hpp>
#include <boost/shared_ptr.hpp>
#include <boost/utility.hpp>
#include <vector>
@@ -34,11 +34,11 @@ public:
/*!
* Make a new clock control object.
* \param iface the usrp_e100 iface object
* \param master clock rate the FPGA rate
* \return the clock control object
*/
- static sptr make(e100_iface::sptr iface, double master_clock_rate);
+ static sptr make(uhd::spi_iface::sptr iface, double master_clock_rate);
/*!
* Set the rate of the fpga clock line.
@@ -34,11 +34,11 @@ public:
/*!
* Make a new clock control object.
- * \param iface the usrp_e100 iface object
+ * \param iface the spi iface object
* \param master clock rate the FPGA rate
* \return the clock control object